Basic usage examples — imbalanced-ensemble 0.1.0 documentation

General-purpose and introductory examples for the imbalanced-ensemble toolbox.

The examples gallery is still under construction. Please refer to APIs for more detailed guidelines of how to use `imbalanced_ensemble`.

# Basic usage examples

Quick start with `imbalanced_ensemble`.

Basic usage example of imbalanced_ensemble

# Dataset examples

Examples concerning the `imbalanced_ensemble.datasets` module.

Create an imbalanced dataset

# Evaluation examples

Examples illustrating how classification using imbalanced dataset can be done.

Evaluate classification by compiling a report

Metrics specific to imbalanced learning

# Pipeline examples

Example of how to use the a pipeline to include under-sampling with scikit-learn estimators.

Usage of pipeline embedding samplers

Gallery generated by Sphinx-Gallery